@@ -70,6 +70,9 @@ async def cloud_mock(loop, aioclient_mock, tmp_path):
 @pytest.fixture
 def auth_cloud_mock(cloud_mock):
     """Return an authenticated cloud instance."""
+    cloud_mock.accounts = MagicMock(
+        instance_resolve_dns_cname=AsyncMock(),
+    )
     cloud_mock.auth.async_check_token.side_effect = AsyncMock()
     cloud_mock.subscription_expired = False
     cloud_mock.instance = MagicMock(
